@@ -17,7 +17,7 @@
 
 #include "dieharder.h"
 
-void time_rng()
+void time_rng(void)
 {
 
  /*
@@ -35,7 +35,9 @@ void time_rng()
  /*
   * Call the actual test that fills in the results struct.
   */
- rgb_timing(rgb_timing_test,&timing);
+ //rgb_timing(rgb_timing_test, &timing);
+ intptr_t *ptr = (intptr_t*) &timing;
+ rgb_timing(rgb_timing_test, (int) *ptr);
 
  /*
   * Save this for display in 
